Flyte Data Catalog Service
============================

Protos provides the interface definition for the Data Catalog Service. Data Catalog is a service to
index parameterized, strongly-typed data artifacts across revisions. It is used in the Flyte ecosystem
to catalog artifacts generated by the task executions. The output generated by a task can be stored as artifact
data and tagged by the user so as to be retrieved later by that tag.

`Datacatalog raw proto <https://github.com/flyteorg/flyteidl/blob/master/protos/flyteidl/datacatalog/datacatalog.proto>`__

.. toctree::
  :maxdepth: 1
  :caption: datacatalog
  :name: datacatalogtoc

  datacatalog
